@@ -1,4 +1,3 @@
-#from util import *
 from .command import *
 
 
@@ -61,7 +60,7 @@ class CommandPSD4SmoothFlow(Command):
         Motor Commands
     """
 
-    def mSetStartVelocity(self, value: int):
+    def setStartVelocity(self, value: int):
         cmd: str = 'v'
         if 50 <= value <= 800:
             cmd += str(value)
@@ -70,7 +69,7 @@ class CommandPSD4SmoothFlow(Command):
             print("Wrong parameter value for set start velocity command!")
         return cmd
 
-    def mSetMaximumVelocity(self, value: int):
+    def setMaximumVelocity(self, value: int):
         cmd: str = 'V'
         if 2 <= value <= 3400:
             cmd += str(value)
@@ -79,7 +78,7 @@ class CommandPSD4SmoothFlow(Command):
             print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
-    def mStopVelocity(self, value: int):
+    def stopVelocity(self, value: int):
         cmd: str = 'c'
         if 50 <= value <= 1700:
             cmd += str(value)
@@ -88,7 +87,7 @@ class CommandPSD4SmoothFlow(Command):
             print("Wrong parameter value for stop velocity command!")
         return cmd
 
-    def mSetMaximumMicroStepVelocity(self, value):
+    def setMaximumMicroStepVelocity(self, value):
         cmd: str = 'u'
         if 400 <= value <= 816000:
             cmd += str(value)
@@ -97,7 +96,7 @@ class CommandPSD4SmoothFlow(Command):
             print("Wrong parameter value for set maximum microstep velocity command!")
         return cmd
 
-    def aStopCommandBuffer(self):
+    def stopCommandBuffer(self):
         return 't'
 
     def syringeDiagnosticTimerValueQuery(self):
