@@ -67,11 +67,6 @@ def waitForResponse(header: str, footer: str):
         print("Pump status: " + responseBit + ' - ' + statusBytesInfo[responseBit])
         if responseBit == '`':
             break
-'''
-def executeCommand(pump, command, waitForPump=False):
-    #pump.checkValidity()
-    return sendCommand(pump.asciiAddress, command, waitForPump)
-'''
 
 def sendCommand(pumpAddress: str, message: str, waitForPump=False):
     commandHeader = '/' + pumpAddress
